@@ -6,7 +6,8 @@ from user_notifications.models import Notification
 # MODEL ADMINS
 ###############
 class NotificationAdmin(admin.ModelAdmin):
-    fields = ('active', 'name', 'sites', 'display_type', 'message', 'rules')
+    fields = ('active', 'deliver_once', 'name', 'sites', 'display_type', 'message', 'rules', 'meta')
+    list_display = ('pk', 'name', 'active', 'deliver_once', 'display_type')
 
 
 admin.site.register(Notification, NotificationAdmin)
\ No newline at end of file
